# shivs_per_lib

This is a small motivational utility + math package by Shivsamb!  
Includes:
- `str_to_int(list)` – Converts string to integer data type of elements in given list
- `int_to_str(list)` – Converts integer to string data type of elements in given list
- `q_mc()` – Returns Final Expressions of given Minterms